==> nextcloud-30.0.10.tgz: nextcloud/apps/app_api/l10n/el.js <==
OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Ακύρωση",
    "Delete" : "Διαγραφή",
    "Password confirmation failed" : "Η επιβεβαίωση του κωδικού πρόσβασης απέτυχε",
    "Default" : "Προεπιλογή",
    "Edit" : "Επεξεργασία",
    "Deploy Daemon" : "Υπηρεσία Ανάπτυξης",
    "Name" : "Όνομα",
    "Host" : "Διακομιστής",
    "Nextcloud URL" : "Διεύθυνση URL του Nextcloud",
    "GPUs support" : "Υποστήριξη GPUs",
    "Compute device" : "Συσκευή υπολογισμού",
    "Enabled" : "Ενεργοποιημένο",
    "Disabled" : "Απενεργοποιημένο",
    "Confirm" : "Επιβεβαίωση",
    "Save" : "Αποθήκευση",
    "Register" : "Εγγραφή",
    "{license}-licensed" : "{license}-αδειοδοτημένο",
    "Update to {version}" : "Ενημέρωση στην έκδοση {version}",
    "Remove" : "Αφαίρεση",
    "Delete data on remove" : "Διαγραφή δεδομένων κατά την αφαίρεση",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει ελάχιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει μέγιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
    "View in store" : "Προβολή στο κέντρο εφαρμογών",
    "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
    "Report a bug" : "Αναφορά σφάλματος",
    "User documentation" : "Τεκμηρίωση χρήστη",
    "Admin documentation" : "Τεκμηρίωση διαχειριστή",
    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
    "This app is supported via your current Nextcloud subscription." : "Αυτή η εφαρμογή υποστηρίζεται μέσω της τρέχουσας συνδρομής σας στο Nextcloud.",
    "Supported" : "Υποστηρίζεται",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι προτεινόμενες εφαρμογές αναπτύσσονται από και εντός της κοινότητας. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για χρήση.",
    "Featured" : "Προτεινόμενες",
    "Update to {update}" : "Ενημέρωση σε {update}",
    "Default Deploy daemon is not accessible" : "Το προεπιλεγμένο Deploy daemon δεν είναι προσβάσιμο",
    "Icon" : "Εικονίδιο",
    "Version" : "Έκδοση",
    "Daemon" : "Υπηρεσία",
    "Level" : "Επίπεδο",
    "Actions" : "Ενέργειες",
    "Results from other categories" : "Αποτελέσματα από άλλες κατηγορίες",
    "_Update_::_Update all_" : ["Ενημέρωση","Ενημέρωση όλων"],
    "Type" : "Τύπος",
    "Display Name" : "Εμφανιζόμενο όνομα",
    "Network" : "Δίκτυο",
    "by {author}\n{license}" : "από {author}\n{license}",
    "Your apps" : "Οι εφαρμογές σας",
    "Documentation" : "Τεκμηρίωση",
    "Details" : "Λεπτομέρειες",
    "Changelog" : "Αρχείο καταγραφής αλλαγών",
    "Active apps" : "Ενεργές εφαρμογές",
    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
    "Updates" : "Ενημερώσεις",
    "Featured apps" : "Προτεινόμενες εφαρμογές",
    "Supported apps" : "Υποστηριζόμενες εφαρμογές",
    "Deploy and Enable" : "Ανάπτυξη και Ενεργοποίηση",
    "Enable" : "Ενεργοποίηση",
    "Disable" : "Απενεργοποίηση",
    "Allow untested app" : "Επιτρέψτε μη δοκιμασμένες εφαρμογές",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Η εφαρμογή δεν είναι συμβατή με την έκδοση Nextcloud σας. Εάν συνεχίσετε μπορείτε να εγκαταστήσετε την εφαρμογή. Η εφαρμογή ίσως να μην λειτουργεί σωστά.",
    "An error occurred during the request. Unable to proceed." : "Προέκυψε σφάλμα κατά την αίτηση. Δεν είναι δυνατή η συνέχεια.",
    "The app has been enabled but needs to be updated." : "Η εφαρμογή έχει ενεργοποιηθεί αλλά χρειάζεται ενημέρωση.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Σφάλμα: Αυτή η εφαρμογή δεν μπορεί να ενεργοποιηθεί γιατί θα καταστήσει ασταθή τον διακομιστή."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.16.tgz: nextcloud/apps/app_api/l10n/el.js <==
OC.L10N.register(
    "app_api",
    {
    "Cancel" : "Ακύρωση",
    "Delete" : "Διαγραφή",
    "Password confirmation failed" : "Η επιβεβαίωση του κωδικού πρόσβασης απέτυχε",
    "Default" : "Προεπιλογή",
    "Edit" : "Επεξεργασία",
    "Deploy Daemon" : "Υπηρεσία Ανάπτυξης",
    "Name" : "Όνομα",
    "Host" : "Διακομιστής",
    "Nextcloud URL" : "Διεύθυνση URL του Nextcloud",
    "GPUs support" : "Υποστήριξη GPUs",
    "Compute device" : "Συσκευή υπολογισμού",
    "Registered Deploy daemons list" : "Κατάλογος εγγεγραμμένων Daemon Ανάπτυξης",
    "No Deploy daemons configured" : "Δεν έχουν ρυθμιστεί Daemon Ανάπτυξης",
    "Register a custom one or setup from available templates" : "Εγγραφή προσαρμοσμένου ή ρύθμιση από διαθέσιμα πρότυπα",
    "Enabled" : "Ενεργοποιημένο",
    "Remove" : "Αφαίρεση",
    "From" : "Από",
    "To" : "Έως",
    "Add" : "Προσθήκη",
    "Display name" : "Εμφανιζόμενο όνομα",
    "Disabled" : "Απενεργοποιημένο",
    "Confirm" : "Επιβεβαίωση",
    "Save" : "Αποθήκευση",
    "Register" : "Εγγραφή",
    "{license}-licensed" : "{license}-αδειοδοτημένο",
    "Update to {version}" : "Ενημέρωση στην έκδοση {version}",
    "Delete data on remove" : "Διαγραφή δεδομένων κατά την αφαίρεση",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει ελάχιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει μέγιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
    "View in store" : "Προβολή στο κέντρο εφαρμογών",
    "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
    "Report a bug" : "Αναφορά σφάλματος",
    "User documentation" : "Τεκμηρίωση χρήστη",
    "Admin documentation" : "Τεκμηρίωση διαχειριστή",
    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
    "This app is supported via your current Nextcloud subscription." : "Αυτή η εφαρμογή υποστηρίζεται μέσω της τρέχουσας συνδρομής σας στο Nextcloud.",
    "Supported" : "Υποστηρίζεται",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι προτεινόμενες εφαρμογές αναπτύσσονται από και εντός της κοινότητας. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για χρήση.",
    "Featured" : "Προτεινόμενες",
    "Update to {update}" : "Ενημέρωση σε {update}",
    "Default Deploy daemon is not accessible" : "Το προεπιλεγμένο Deploy daemon δεν είναι προσβάσιμο",
    "Icon" : "Εικονίδιο",
    "Version" : "Έκδοση",
    "Daemon" : "Υπηρεσία",
    "Level" : "Επίπεδο",
    "Actions" : "Ενέργειες",
    "Results from other categories" : "Αποτελέσματα από άλλες κατηγορίες",
    "_Update_::_Update all_" : ["Ενημέρωση","Ενημέρωση όλων"],
    "Type" : "Τύπος",
    "Display Name" : "Εμφανιζόμενο όνομα",
    "Network" : "Δίκτυο",
    "by {author}\n{license}" : "από {author}\n{license}",
    "Your apps" : "Οι εφαρμογές σας",
    "Documentation" : "Τεκμηρίωση",
    "Details" : "Λεπτομέρειες",
    "Changelog" : "Αρχείο καταγραφής αλλαγών",
    "Active apps" : "Ενεργές εφαρμογές",
    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
    "Updates" : "Ενημερώσεις",
    "Featured apps" : "Προτεινόμενες εφαρμογές",
    "Supported apps" : "Υποστηριζόμενες εφαρμογές",
    "Deploy and Enable" : "Ανάπτυξη και Ενεργοποίηση",
    "Enable" : "Ενεργοποίηση",
    "Disable" : "Απενεργοποίηση",
    "Allow untested app" : "Επιτρέψτε μη δοκιμασμένες εφαρμογές",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Η εφαρμογή δεν είναι συμβατή με την έκδοση Nextcloud σας. Εάν συνεχίσετε μπορείτε να εγκαταστήσετε την εφαρμογή. Η εφαρμογή ίσως να μην λειτουργεί σωστά.",
    "An error occurred during the request. Unable to proceed." : "Προέκυψε σφάλμα κατά την αίτηση. Δεν είναι δυνατή η συνέχεια.",
    "The app has been enabled but needs to be updated." : "Η εφαρμογή έχει ενεργοποιηθεί αλλά χρειάζεται ενημέρωση.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Σφάλμα: Αυτή η εφαρμογή δεν μπορεί να ενεργοποιηθεί γιατί θα καταστήσει ασταθή τον διακομιστή."
},
"nplurals=2; plural=(n != 1);");
